@@ -375,11 +375,11 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
 
         return values
 
-    def gradient_eval_predictor_importance(self, features, actual_predictions, features_names, display = False):
+    def gradient_eval_predictor_importance(self, features, actual_predictions, features_names, n_samples, display = False):
         explainer_shap = shap.GradientExplainer(model=self,
                                             data=features)
         # Fit the explainer on a subset of the data (you can try all but then gets slower)
-        shap_values = explainer_shap.shap_values(features,nsamples = 500, ranked_outputs=True,output_rank_order='max',rseed=None,return_variances=False)
+        shap_values = explainer_shap.shap_values(features,nsamples = n_samples, ranked_outputs=True,output_rank_order='max',rseed=None,return_variances=False)
         predictors_shap_values = shap_values[0]
         predictors_feature_order = np.argsort(np.sum(np.mean(np.abs(predictors_shap_values), axis=0), axis=0))
 
@@ -443,7 +443,7 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
         self.last_test_slice = test_slice
         return eval_slice, test_slice, predictors, tt, tt_true
 
-    def unroll_features(self, dates, feature_names, display_slices = False, gradient = False):
+    def unroll_features(self, dates, feature_names, display_slices = False, gradient = True, n_samples = 5000):
         self.handle_callback('begin_fit')
         rows_list = []
         dates_list = []
@@ -459,7 +459,7 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
             me_pred = torch.cat((eval_prediction, test_prediction), 0)
             me_features = torch.cat((self.X[eval_slice], self.X[test_slice]), 0)
             if gradient :
-                features_dico = self.gradient_eval_predictor_importance(me_features, me_pred, feature_names)
+                features_dico = self.gradient_eval_predictor_importance(me_features, me_pred, feature_names, n_samples)
             else:
                 features_dico = self.eval_predictor_importance(me_features, me_pred, feature_names)
             rows_list.append(features_dico)
